#
# spec file for package cgal
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2014 Ioda-Net Sàrl, Charmoille, Switzerland.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#@TODO : clarify and split licence correctly, GPL & LGPL 3+ version
#@TODO : split package in coherent parts
#@TODO : rename parts (inspirated by sfcgal packaging)
#@TODO : ask for rename and take into account the obsolete existant thing. like libcgal deps
# soversions, according to Installation/CMakeLists.txt
#   CGAL-4.14  : 14.0.0 , but only for CGAL_ImageIO (ABI broken in CGAL::Image_3.)
#                              and for CGAL_Qt5 (ABI broken in DemoMainWindow)
#   CGAL-4.14  : 13.0.3 , for other libraries
%define _sover 13
%define _sover_Core 13
%define _sover_ImageIO 14
%define _sover_Qt5 14
%define _sourcename CGAL
%define _libname() libCGAL%{?1}%{?2}%{expand:%{_sover%{?1}}}
# Disable Qt5 for embedded platforms, QOpenGlFunctions_2_1 is not available with GLES
%ifarch %{arm} aarch64
%bcond_with qt5
%else
%bcond_without qt5
%endif
Name:           cgal
Version:        5.2.1
Release:        bp154.1.108
Summary:        Computational Geometry Algorithms Library
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Productivity/Graphics/CAD
URL:            https://www.cgal.org/
Source0:        https://github.com/CGAL/cgal/releases/download/v%{version}/CGAL-%{version}.tar.xz
Source1:        https://github.com/CGAL/cgal/releases/download/v%{version}/CGAL-%{version}-doc_html.tar.xz
Source2:        cgal-rpmlintrc
BuildRequires:  blas-devel
BuildRequires:  cmake >= 2.8.11
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glu-devel
BuildRequires:  gmp-devel
BuildRequires:  lapack-devel
BuildRequires:  libboost_atomic-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  mpfr-devel
BuildRequires:  xz
BuildRequires:  zlib-devel
Requires:       libcgal-devel = %{version}
%if %{with qt5}
BuildRequires:  cmake(Qt5) >= 5.3
BuildRequires:  cmake(Qt5OpenGL) >= 5.3
BuildRequires:  cmake(Qt5Svg) >= 5.3
BuildRequires:  cmake(Qt5Xml) >= 5.3
%endif

%description
CGAL provides geometric algorithms in a C++ library.

The library offers data structures and algorithms like
triangulations, Voronoi diagrams, Boolean operations on polygons and
polyhedra, point set processing, arrangements of curves, surface and
volume mesh generation, geometry processing, alpha shapes, convex
hull algorithms, shape analysis, AABB and KD trees.

%package -n %{_libname}
Summary:        Computational Geometry Algorithms Library
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          System/Libraries

%description -n %{_libname}
CGAL provides geometric algorithms in a C++ library.

The library offers data structures and algorithms like
triangulations, Voronoi diagrams, Boolean operations on polygons and
polyhedra, point set processing, arrangements of curves, surface and
volume mesh generation, geometry processing, alpha shapes, convex
hull algorithms, shape analysis, AABB and KD trees.

%package -n %{_libname _Core}
Summary:        Computational Geometry Algorithms Library
# Required after package split, remove on sover bump
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          System/Libraries
Conflicts:      %{_libname} < %{version}

%description -n %{_libname _Core}
CGAL provides geometric algorithms in a C++ library.

The library offers data structures and algorithms like
triangulations, Voronoi diagrams, Boolean operations on polygons and
polyhedra, point set processing, arrangements of curves, surface and
volume mesh generation, geometry processing, alpha shapes, convex
hull algorithms, shape analysis, AABB and KD trees.

%package -n %{_libname _ImageIO}
Summary:        Computational Geometry Algorithms Library
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          System/Libraries

%description -n %{_libname _ImageIO}
CGAL provides geometric algorithms in a C++ library.

The library offers data structures and algorithms like
triangulations, Voronoi diagrams, Boolean operations on polygons and
polyhedra, point set processing, arrangements of curves, surface and
volume mesh generation, geometry processing, alpha shapes, convex
hull algorithms, shape analysis, AABB and KD trees.

%package -n %{_libname _Qt5 - }
Summary:        Computational Geometry Algorithms Library
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          System/Libraries

%description -n %{_libname _Qt5 - }
CGAL provides geometric algorithms in a C++ library.

The library offers data structures and algorithms like
triangulations, Voronoi diagrams, Boolean operations on polygons and
polyhedra, point set processing, arrangements of curves, surface and
volume mesh generation, geometry processing, alpha shapes, convex
hull algorithms, shape analysis, AABB and KD trees.

%package devel
Summary:        Development files and tools for CGAL applications
License:        GPL-3.0-or-later AND LGPL-3.0-or-later AND BSL-1.0
Group:          Development/Libraries/C and C++
Requires:       %{_libname} = %{version}
Requires:       %{_libname _Core} = %{version}
Requires:       %{_libname _ImageIO} = %{version}
Requires:       blas
Requires:       cmake
Requires:       gmp-devel
Requires:       lapack
Requires:       libboost_atomic-devel
Requires:       libboost_system-devel
Requires:       libboost_thread-devel
Requires:       mpfr-devel
Requires:       zlib-devel
#For compatibility with package looking for our old name
Provides:       libcgal-devel = %{version}
%if %{with qt5}
Requires:       %{_libname _Qt5 - } = %{version}
%endif

%description devel
This package provides the headers files and tools you may need to
develop applications using CGAL.

%package demo-examples-devel
Summary:        Example & demo files for CGAL library usage
License:        GPL-3.0-or-later AND LGPL-3.0-or-later AND BSL-1.0 AND MIT
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
BuildArch:      noarch

%description demo-examples-devel
This package provides the sources of examples and demos of
CGAL algorithms. You can study them, compile and test CGAL
library.

%package doc
Summary:        Documentation CGAL algorithms
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides the documentation for CGAL algorithms.

%prep
%setup -q -n CGAL-%{version} -a1

%build
%cmake -DCGAL_HEADER_ONLY=OFF \
       -DCGAL_INSTALL_LIB_DIR=%{_lib}

%make_build

# Unfortunately take +6600sec locally.
# So we just deliver the source code in cgal package.
#  -DWITH_examples=true \
#  -DWITH_demos=true \

%install
%cmake_install

install -d %{buildroot}/%{_datadir}/CGAL/examples
install -d %{buildroot}/%{_datadir}/CGAL/demo
cp -a examples/* %{buildroot}/%{_datadir}/CGAL/examples
cp -a demo/* %{buildroot}/%{_datadir}/CGAL/demo

# Clean doc wrongly placed by make install
rm -rfv %{buildroot}/%{_datadir}/doc/CGAL

# no macos here.
rm %{buildroot}/%{_bindir}/cgal_make_macosx_app

install -d %{buildroot}/%{_docdir}/%{name}-doc/
cp -a doc_html %{buildroot}/%{_docdir}/%{name}-doc/
%fdupes %{buildroot}%{_docdir}/%{name}-doc/

%fdupes %{buildroot}/%{_datadir}

%post -n %{_libname} -p /sbin/ldconfig
%postun -n %{_libname} -p /sbin/ldconfig
%post -n %{_libname _Core} -p /sbin/ldconfig
%postun -n %{_libname _Core} -p /sbin/ldconfig
%post -n %{_libname _Qt5 - } -p /sbin/ldconfig
%postun -n %{_libname _Qt5 - } -p /sbin/ldconfig
%post -n %{_libname _ImageIO} -p /sbin/ldconfig
%postun -n %{_libname _ImageIO} -p /sbin/ldconfig

%files -n %{_libname}
%license LICENSE*
%{_libdir}/libCGAL.so.%{_sover}*

%files -n %{_libname _Core}
%{_libdir}/libCGAL_Core.so.%{_sover_Core}*

%files -n %{_libname _ImageIO}
%{_libdir}/libCGAL_ImageIO.so.%{_sover_ImageIO}*

%if %{with qt5}
%files -n %{_libname _Qt5 - }
%{_libdir}/libCGAL_Qt5.so.%{_sover_Qt5}*
%endif

%files devel
%license LICENSE*
%doc AUTHORS CHANGES.md
%{_includedir}/CGAL
%{_libdir}/libCGAL.so
%{_libdir}/libCGAL_Core.so
%{_libdir}/libCGAL_ImageIO.so
%if %{with qt5}
%{_libdir}/libCGAL_Qt5.so
%endif
%{_libdir}/cmake/CGAL
%{_bindir}/*
%{_mandir}/man1/cgal_create_cmake_script.1%{?ext_man}

%files demo-examples-devel
%license LICENSE*
%{_datadir}/CGAL

%files doc
%license LICENSE*
%doc AUTHORS CHANGES.md
%doc %{_docdir}/%{name}-doc/doc_html

%changelog
* Tue Apr 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 5.2.1
  * See https://github.com/CGAL/cgal/pulls?utf8=%%E2%%9C%%93&q=label%%3AMerged_in_5.2.1
- Update to 5.2.0
  * Fixed multiple code execution vulnerabilities:
    boo#1184975 ( CVE-2020-35636 ), boo#1184977 ( CVE-2020-28636 ),
    boo#1184973 ( CVE-2020-28601 ) and boo#1184978 ( CVE-2020-35628 )
  * For full list of other changes, see:
    https://www.cgal.org/2020/12/22/cgal52/
* Wed Nov 18 2020 Michael Vetter <mvetter@suse.com>
- Update to 5.1.1:
  See https://github.com/CGAL/cgal/pulls?utf8=%%E2%%9C%%93&q=label%%3AMerged_in_5.1.1
* Fri Oct  2 2020 Dirk Stoecker <opensuse@dstoecker.de> 5.1
- update to version 5.1
  Many news, see https://github.com/CGAL/cgal/releases/tag/v5.1
* Sun Mar 29 2020 Simon Puchert <simonpuchert@alice.de> 5.0.2
- Update to version 5.0.2
  * various small bugfixes
- Update to version 5.0.1
  * fixes a performance regression in 3D Triangulations, when using
    the Parallel_tag
- Update to version 5.0.0
  * requires g++ 6.3 or later
  * requires boost 1.57.0 or later
  * new Polygonal Surface Reconstruction
  * See https://www.cgal.org/2019/11/08/cgal50/ for details
- manually disable header-only build
* Tue Jul 30 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build on x86_64 and some other, do not force -fPIE, -fPIC would be
  needed but is the default already.
* Fri Apr  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add Conflicts between libCGAL_core and old unsplit package, both
  provide the same library file.
* Thu Apr  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split library package into 4 subpackages, libCGAL, libCGAL_Core
  libCGAL_ImageIO and libCGAL_Qt5, to properly adhere to the
  Shared Libraray Packaging policy, versions are no longer in sync.
- Add bcond for Qt5 component. It requires Qt5 built with Desktop
  OpenGL support, which is not available on ARM and Aarch64.
- Remove fdupes filter from rpmlintrc, not required any more.
* Mon Apr  1 2019 mvetter@suse.com
- Update to 4.14:
  * new 2D Periodic Hyperbolic Triangulations
  * new 2D Hyperbolic Triangulations
  * new The Heat Method
  * new Triangulated Surface Mesh Approximation
  * For bugfixes and details see:
    https://www.cgal.org/2019/03/29/cgal414/
* Tue Oct  2 2018 mvetter@suse.com
- Update to 4.13:
  * Added: 3D Periodic Mesh Generation
  * Classification package can now handle classification of surface
  meshes and clusters, and can compute features in parallel.
  * For list of more changes and bugfixes see:
    https://www.cgal.org/2018/10/01/cgal413/
* Wed Sep  5 2018 mvetter@suse.com
- Update to 4.12.1:
  Please see https://github.com/CGAL/cgal/milestone/33?closed=1
  for the full list of fixed bugs
* Mon Jun 18 2018 stefan.bruens@rwth-aachen.de
- Use correct BuildRequires for libboost_atomic-devel
- Manually install documentation, %%doc does not preserve symlinks
- Cleanup
* Mon Apr 30 2018 jengelh@inai.de
- Use %%setup logic to extract supplementary source archives.
* Thu Apr 26 2018 mvetter@suse.com
- Remove cgal-4.11-opengl-es-arm.patch: upstreamed
- Update to 4.12:
  * New 2D Movable Separability of Sets
  * Classification: algorithm that classifies a data set into a
    user-defined set of labels
  * Removed Kinetic Data Structures
  * See https://www.cgal.org/2018/04/25/cgal412/ for a complete
    list of changes
* Tue Feb 27 2018 mvetter@suse.com
- Update to 4.11.1:
  * Bug fix release
    Please see https://github.com/CGAL/cgal/milestone/28?closed=1
  for the full list of fixed bugs
* Thu Dec  7 2017 normand@linux.vnet.ibm.com
- remove in spec the Requires: qt-devel that is Qt4 related
* Wed Sep 27 2017 mvetter@suse.com
- Always use Qt5
* Wed Sep 27 2017 mvetter@suse.com
- boo#1060631: Add cgal-4.11-opengl-es-arm.patch
  On armv7 Qt uses OpenGL ES headers.
  cgal included GL/gl.h desktop header, but they cannot be mixed.
* Wed Sep 27 2017 mvetter@suse.com
- Remove boost conditionals. They are handled in prj conf.
* Tue Sep 26 2017 mvetter@suse.com
- Update to 4.11
  * details can be found in CHANGES file
* Tue Feb  7 2017 jengelh@inai.de
- Redo description and RPM groups
- Rename %%_soname to %%_sover to better reflect its use
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Nov 22 2015 wk@ire.pw.edu.pl
- fixed build for SLE-12 and some earlier releases
* Tue Nov 17 2015 mpluskal@suse.com
- Update to 4.7
  * switch to qt5
  * details can be found in CHANGES file
- Use github for download urls
* Mon Sep 28 2015 mpluskal@suse.com
- Update to 4.6.3
  * details can be found in CHANGES file
* Tue Sep  1 2015 dimstar@opensuse.org
- Fix Source URLs.
* Wed Aug 19 2015 adrian@suse.de
- Update to 4.6.1
  * details can be found in CHANGES file
* Sat Feb 28 2015 mpluskal@suse.com
- Remove conditionals and use only cmake macros for building
* Sat Feb 28 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Remove sha256sum.txt
- Update to 4.5.2
  * Fix a bug that prevented the compilation with recent versions
    of Boost (>=1.56) when explicit conversions operators
    (from C++11) are supported. That prevented the compilation with
    Microsoft Visual Studio 2013.
  * 3D Convex Hulls: Fix a non-robust predicate bug that was
    showing up when input points where lexicographically sorted.
  * 3D Mesh Generation: Fix a bug in the sliver perturbation
    optimization method. It could create some holes on the
    surface of the mesh.
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 4.5.1,http://www.cgal.org/releases.html#release4.5.1
- Bump sover to 10.0.4
* Tue Jun  3 2014 bruno@ioda-net.ch
- update to 4.4, see http://www.cgal.org/releases.html#release4.4
- packaging : remove libcgal%%soname as main package
- cgal is dumb empty package
- libcgalsoname contain only library
- cgal-demo-examples-devel contain all demo and example
- cgal-doc contain the whole documentation
- Fix & cleanup Licence as specified in sources
- Make it build for SLE with exception for noarch.
* Tue Dec 17 2013 coolo@suse.com
- update to 4.3, see http://www.cgal.org/releases.html#release4.3
* Sat Jan 19 2013 prusnak@opensuse.org
- updated to 4.1
* Fri Aug  3 2012 jw@suse.com
- added happy_gcc.patch
  fixed c++ syntax for a more strict gcc
* Fri Aug  3 2012 jw@suse.com
- fixed Group and License
* Fri Aug  3 2012 jw@suse.com
- added boost149workaround.patch
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to 3.9
* Sat May 14 2011 prusnak@opensuse.org
- don't build Qt3 library anymore
- use fdupes
* Fri May 13 2011 prusnak@opensuse.org
- based on a Fedora package by Laurent Rineau (version 3.8)
